import { entries, createPreviewValue, getOwnDescriptorsIn, isBuffer, getOwnDescriptorsBuffer, isCollection, getOwnDescriptorsCollection, isDataView, getOwnDescriptorsDataView, isRegExp, getOwnDescriptorsRegExp, isTypedArray, getOwnDescriptorsTypedArray } from './chunk-F6PJIKRF.mjs';

// src/logic/isArrayEmpty.ts
function isArrayEmpty(arr) {
  for (const name in arr) {
    if (Number.isNaN(+name))
      return true;
    return false;
  }
  return true;
}

// src/logic/Table.ts
function getExtendsPropertyDescriptors(data) {
  if (data === null || typeof data !== "object")
    return;
  if (isBuffer(data))
    return getOwnDescriptorsBuffer(data);
  if (isCollection(data))
    return getOwnDescriptorsCollection(data);
  if (isDataView(data))
    return getOwnDescriptorsDataView(data);
  if (isRegExp(data))
    return getOwnDescriptorsRegExp(data);
  if (isTypedArray(data))
    return getOwnDescriptorsTypedArray(data);
  return void 0;
}
function getDescriptors(data) {
  return Object.assign(
    getOwnDescriptorsIn(data),
    Object.getOwnPropertyDescriptors(data),
    getExtendsPropertyDescriptors(data)
  );
}
function Table(data) {
  const table = {};
  const nameCols = /* @__PURE__ */ new Set();
  entries(getDescriptors(data)).forEach(([name, meta]) => {
    name = name.toString();
    const { value } = meta;
    let isArray;
    if (value !== null && typeof value === "object" && (!(isArray = Array.isArray(value)) || !isArrayEmpty(value))) {
      const row = table[name] = {};
      entries(getDescriptors(value)).forEach(([propName, propMeta]) => {
        if (isArray && propName === "length")
          return;
        propName = propName.toString();
        nameCols.add(propName);
        row[propName] = createPreviewValue(propMeta.value);
      });
    } else {
      nameCols.add("Values");
      table[name] = {
        Values: createPreviewValue(value)
      };
    }
  });
  return {
    table,
    cols: Array.from(nameCols.values())
  };
}

export { Table };
